@@ -1,10 +1,10 @@
-use v5.10;
+use v5.10.1;
 use strict;
 use warnings;
 
 package RTx::FillTicketData;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
